%global srcname uutf

Name:           ocaml-uutf
Version:        1.0.2
Release:        %mkrel 4
Summary:        Non-blocking streaming codec for UTF-8, UTF-16, UTF-16LE and UTF-16BE
License:        BSD3
Group:          Development/OCaml
URL:            http://erratique.ch/software/uutf
#Source0:        http://erratique.ch/software/uutf/releases/uutf-%{version}.tbz
Source0:        https://github.com/dbuenzli/uutf/archive/v%{version}/%{srcname}-%{version}.tar.gz
# The uchar package is a forward compatibility package for OCaml versions prior
# to 4.03.  We have a later OCaml in Fedora; uchar is in the standard library.
# Therefore, remove references to the compatibility package.
Patch0:         %{name}-uchar.patch
BuildRequires:  ocaml-findlib
BuildRequires:  ocaml-compiler
BuildRequires:  ocaml-ocamlbuild
BuildRequires:  ocaml-cmdliner-devel
BuildRequires:  ocaml-topkg-devel

%description
Uutf is an non-blocking streaming Unicode codec for OCaml to decode and
encode the UTF-8, UTF-16, UTF-16LE and UTF-16BE encoding schemes. It can
efficiently work character by character without blocking on IO. Decoders
perform character position tracking and support newline normalization.

Functions are also provided to fold over the characters of UTF encoded OCaml
string values and to directly encode characters in OCaml Buffer.t values.

Uutf is made of a single, independent, module.

%package        devel
Summary:        Development files for %{name}
Group:          Development/OCaml
Requires:       %{name} = %{version}-%{release}

%description    devel
The %{name}-devel package contains libraries and signature files for
developing applications that use %{name}.

%prep
%autosetup -n %{srcname}-%{version} -p1

# require debug info
echo $'\ntrue: debug' >> _tags

sed -i 's|bin_annot|bin_annot, annot|' _tags

%build
ocaml pkg/pkg.ml build

%install
export DESTDIR=%{buildroot}
export OCAMLFIND_DESTDIR=%{buildroot}%{_libdir}/ocaml
mkdir -p $OCAMLFIND_DESTDIR/uutf
pushd _build/src/
 ocamlfind install uutf ../pkg/META \
   *.a *.cm[iatx] *.cmti *.cmx[as] *.annot *.mli
popd

install -d %{buildroot}%{_bindir}/
install -m 0755 _build/test/utftrip.native %{buildroot}%{_bindir}/utftrip

# Makes *.cmxs executable such that they will be stripped.
find %{buildroot} -name '*.cmxs' -exec chmod 0755 {} \;

%files
%doc README.md CHANGES.md
%dir %{_libdir}/ocaml/uutf
%{_libdir}/ocaml/uutf/META
%{_libdir}/ocaml/uutf/*.cma
%{_libdir}/ocaml/uutf/*.cmi
%{_libdir}/ocaml/uutf/*.cmxs
%{_bindir}/utftrip

%files devel
%doc doc/
%doc test/
%{_libdir}/ocaml/uutf/*.a
%{_libdir}/ocaml/uutf/*.cmxa
%{_libdir}/ocaml/uutf/*.cmx
%{_libdir}/ocaml/uutf/*.mli
%{_libdir}/ocaml/uutf/*.cmt
%{_libdir}/ocaml/uutf/*.cmti
%{_libdir}/ocaml/uutf/*.annot


%changelog
* Sun Jan 10 2021 pterjan <pterjan> 1.0.2-4.mga8
+ Revision: 1670677
- Rebuild to generate ocamlx provides

* Fri Feb 28 2020 umeabot <umeabot> 1.0.2-3.mga8
+ Revision: 1551668
- Rebuild for ocaml 4.10.0 final

* Wed Feb 19 2020 umeabot <umeabot> 1.0.2-2.mga8
+ Revision: 1543646
- Mageia 8 Mass Rebuild

* Wed Jan 22 2020 tv <tv> 1.0.2-1.mga8
+ Revision: 1482007
- new release + rebuild for ocaml-4.10

* Tue Oct 23 2018 pterjan <pterjan> 1.0.1-2.mga7
+ Revision: 1324544
- Rebuild for ocaml 4.07.1

* Wed Aug 29 2018 daviddavid <daviddavid> 1.0.1-1.mga7
+ Revision: 1255534
- new version: 1.0.1
- need ocaml-compiler and ocaml-topkg

* Wed Aug 29 2018 daviddavid <daviddavid> 0.9.4-5.mga7
+ Revision: 1255397
- rebuild for new ocaml-result 1.3

* Sat Mar 24 2018 daviddavid <daviddavid> 0.9.4-4.mga7
+ Revision: 1211799
- rebuild for new ocaml-cmdliner

* Mon Jan 22 2018 tv <tv> 0.9.4-3.mga7
+ Revision: 1196248
- BR ocamlbuild
- fix build with ocaml-4.06
- rebuild for new ocaml

* Fri Oct 06 2017 daviddavid <daviddavid> 0.9.4-2.mga7
+ Revision: 1169711
- enable debugging information thus fixing empty debugsourcefiles.list

* Tue Feb 09 2016 pterjan <pterjan> 0.9.4-1.mga6
+ Revision: 951009
- Fix BuildRequires
- Update to 0.9.4

* Wed Oct 15 2014 umeabot <umeabot> 0.9.3-5.mga5
+ Revision: 749971
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0.9.3-4.mga5
+ Revision: 683126
- Mageia 5 Mass Rebuild

* Mon Oct 21 2013 umeabot <umeabot> 0.9.3-3.mga4
+ Revision: 537831
- Mageia 4 Mass Rebuild

* Fri Sep 27 2013 blue_prawn <blue_prawn> 0.9.3-2.mga4
+ Revision: 487866
- rebuild for ocaml-4.01.0

* Fri Sep 06 2013 blue_prawn <blue_prawn> 0.9.3-1.mga4
+ Revision: 475540
- updated to last version 0.9.3

* Sun Jan 13 2013 umeabot <umeabot> 0.9.2-2.mga3
+ Revision: 361693
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Mon Jan 07 2013 malo <malo> 0.9.2-1.mga3
+ Revision: 341176
- new version 0.9.2

* Mon Oct 01 2012 blue_prawn <blue_prawn> 0.9.1-4.mga3
+ Revision: 301077
- rebuild for ocaml-4.00.0

* Sat Sep 29 2012 blue_prawn <blue_prawn> 0.9.1-3.mga3
+ Revision: 300427
- increm mkrel

* Fri Sep 28 2012 blue_prawn <blue_prawn> 0.9.1-2.mga3
+ Revision: 299125
- new rpm group for ocaml

* Sun Sep 09 2012 blue_prawn <blue_prawn> 0.9.1-1.mga3
+ Revision: 291356
- updated to last version 0.9.1

* Sun May 06 2012 blue_prawn <blue_prawn> 0.9.0-1.mga3
+ Revision: 234847
- imported package ocaml-uutf

